---
title: Generating Badges
description: "This includes the steps on how to generate the readme badge for coverage"
date: Jan 24, 2026
---

Render Engine shows a badge of it's coverage report and other information.

This badge is generated using [genbadge].

The badge is autogenerated via github actions. To manually generate a new badge, you can run the following commands.

```bash
uv run extra=dev pytest --cov-report xml
uvx --with "genbadge[coverage]" genbadge coverage -i coverage.xml
```

You can generate this badge with just:

```bash
just badge
```

[genbadge]: https://smarie.github.io/python-genbadge/
